@@ -21,6 +21,7 @@ class BaseUpdateTask:
         load_state_func: Optional[Callable],
         queue_identifiers: List[str],
         channel_identifiers: Dict[str, str],
+        lock_identifier: str,
         redis_params: Dict[str, Any],
         running: Any,
     ):
@@ -34,16 +35,20 @@ class BaseUpdateTask:
         self.routes = routes
         self.queue_identifiers = queue_identifiers
         self.channel_identifiers = channel_identifiers
+        self.lock_identifier = lock_identifier
 
         self.running = running
         self.daemon = True
 
-        self.redis_con = redis.Redis(**redis_params)
+        self.redis_params = redis_params
+        self.redis_con: Optional[redis.Redis] = None
 
     def __del__(self) -> None:
-        self.redis_con.close()
+        if self.redis_con is not None:
+            self.redis_con.close()
 
     def custom_run(self) -> None:
+        self.redis_con = redis.Redis(**self.redis_params)
         redis_con = self.redis_con
 
         while self.running.value:
@@ -64,7 +69,7 @@ class BaseUpdateTask:
                 # if flush_update:
                 #     break
             except redis.exceptions.ConnectionError:
-                logger.error("Connection to redis lost.")
+                logger.error("Connection to redis lost.", exc_info=True)
                 break
 
             # Check if we should stop
@@ -91,12 +96,15 @@ class BaseUpdateTask:
 
             # Run update op
             try:
-                with redis_con.lock(f"MOTION_LOCK:{self.instance_name}", timeout=120):
-                    old_state = loadState(
+                with redis_con.lock(self.lock_identifier, timeout=120):
+                    old_state, version = loadState(
                         redis_con,
                         self.instance_name,
                         self.load_state_func,
                     )
+                    if old_state is None:
+                        raise ValueError(f"State for {self.instance_name} not found.")
+
                     state_update = self.routes[queue_name].run(
                         state=old_state,
                         props=item["props"],
@@ -107,12 +115,14 @@ class BaseUpdateTask:
 
                     if not isinstance(state_update, dict):
                         logger.error(
-                            "Update methods should return a dict of state updates."
+                            "Update methods should return a dict of state updates.",
+                            exc_info=True,
                         )
                     else:
                         old_state.update(state_update)
                         saveState(
                             old_state,
+                            version,
                             redis_con,
                             self.instance_name,
                             self.save_state_func,
